VERSION = (23, 2, 3, "")

__version_info__ = VERSION
__version__ = ".".join(map(str, VERSION[:3])) + (f"-{VERSION[3]}" if VERSION[3] else "")

__author__ = "Grzegorz Król"
__license__ = "BSD-3-Clause"
__copyright__ = "Copyright 2021-2023 Grzegorz Król and contributors"



# Generated by Django 4.1.3 on 2023-01-27 23:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("cjkcms", "0004_layoutsettings_articles_date_format_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="layoutsettings",
            name="custom_font",
            field=models.BooleanField(
                default=False,
                help_text="Custom body font e.g. from CDN & include css body override",
                verbose_name="Use custom font",
            ),
        ),
        migrations.AddField(
            model_name="layoutsettings",
            name="font_family",
            field=models.CharField(
                blank=True,
                default="Roboto, sans-serif",
                help_text="Font family name, e.g. 'Open Sans, sans-serif'",
                max_length=128,
                verbose_name="Font Family",
            ),
        ),
        migrations.AddField(
            model_name="layoutsettings",
            name="font_url",
            field=models.CharField(
                blank=True,
                default="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;500;700&display=swap",
                help_text="Full URL to font css file",
                max_length=250,
                verbose_name="Font URL",
            ),
        ),
        migrations.AlterField(
            model_name="layoutsettings",
            name="awesome_cdn",
            field=models.BooleanField(
                default=False,
                help_text="Load font awesome from CDN",
                verbose_name="Font Awesome",
            ),
        ),
    ]



# Generated by Django 4.1.6 on 2023-02-20 22:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailcore", "0083_workflowcontenttype"),
        ("cjkcms", "0005_layoutsettings_custom_font_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="analyticssettings",
            name="consent_modal_layout",
            field=models.CharField(
                choices=[("box", "Box"), ("cloud", "Cloud"), ("bar", "Bar")],
                default="cloud",
                help_text="Layout of the cookie consent modal",
                max_length=6,
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="contact_page",
            field=models.ForeignKey(
                blank=True,
                help_text="Show [More info] section with link to selected contact page in cookie consent settings.",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="wagtailcore.page",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="cookie_consent",
            field=models.BooleanField(
                default=False,
                help_text="Enable simple GDPR compliant cookie consent banner. Intended as a quick solution for sites that don't need a fully customisable consent.",
                verbose_name="Enable cookie consent",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="cookie_consent_deny_btn",
            field=models.BooleanField(
                default=False,
                help_text="Show an [Accept Necessary Only] button in the cookie consent banner. If unchecked, the banner will only have an accept and settings buttons.",
                verbose_name="Show Accept Necessary",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="privacy_page",
            field=models.ForeignKey(
                blank=True,
                help_text="Show a link to selected privacy policy page in cookie consent settings.",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="+",
                to="wagtailcore.page",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="settings_modal_layout",
            field=models.CharField(
                choices=[("box", "Box"), ("bar", "Bar")],
                default="box",
                help_text="Layout of the full cookie consent settings modal.",
                max_length=6,
            ),
        ),
    ]



from django.core.management.base import BaseCommand
from wagtail.models import Page
from django.apps import apps


class Command(BaseCommand):
    """
    # Delete the default home page generated by wagtail,
    # and replace it with a more useful page type based on CMS.
    # Unless specific class is given, use the cjkcms.WebPage
    """

    help = "Replaces the default Wagtail HomePage with a CMS page"

    def add_arguments(self, parser):
        # Named (optional) arguments
        parser.add_argument(
            "--force",
            action="store_true",
            help="Force overwrite if more than a homepage already exists",
        )

        parser.add_argument(
            "--host_name",
            action="store",
            default="localhost",
            help="Custom hostname for the new site",
        )

        parser.add_argument(
            "--site_name",
            action="store",
            default="devsite",
            help="Custom site name for the new site",
        )

        parser.add_argument(
            "--page_app",
            action="store",
            default="cjkcms",
            help="Custom app to use for the new homepage. Defaults to `cjkcms`",
        )

        parser.add_argument(
            "--page_model",
            action="store",
            default="WebPage",
            help="Custom class to use for the new homepage. Defaults to WebPage",
        )

    def handle(self, raise_error=False, *args, **options):
        # check if ok to overwrite (force == 1)
        force = options["force"]
        verbosity = options["verbosity"]
        checks = [Page.objects.count() > 2]  # root + home = 2
        page_app = options["page_app"]
        page_model = options["page_model"]
        host_name = options["host_name"]
        site_name = options["site_name"]

        if any(checks) and not force:
            # YOU SHOULD NEVER RUN THIS COMMAND WITHOUT PRIOR DB DUMP
            raise RuntimeError(
                "Found more pages than Root+Home. Aborting. use force=1 to overwrite"
            )

        self.setup_homepage(page_app, page_model, host_name, site_name)
        if verbosity > 0:
            msg = "New homepage + site successfully created."
            self.stdout.write(msg)

    def setup_homepage(
        self, page_app: str, page_model: str, host_name: str, site_name: str
    ):
        ContentType = apps.get_model("contenttypes.ContentType")
        Site = apps.get_model("wagtailcore.Site")
        CustomPage = apps.get_model(f"{page_app}.{page_model}")

        # Create or read cms page content type
        cms_page_content_type, created = ContentType.objects.get_or_create(  # type: ignore
            model=page_model,
            app_label=page_app,
        )

        # Delete the default home page generated by wagtail,
        # and replace it with a more useful page type.
        # Note: this also deletes the default site
        _ = Page.objects.filter(slug="home").delete()

        try:
            root_page = Page.objects.get(path="0001")
        except Page.DoesNotExist:
            # root page not found, something is seriously wrong
            exit()

        homepage = CustomPage(  # type: ignore
            title="Home",
            slug="home",
            content_type=cms_page_content_type,
            # path="00010001",
            # depth=2,
            # numchild=0,
            # url_path="/home/",
            # locale_id=Locale.get_default().id,
        )
        root_page.add_child(instance=homepage)
        homepage.save_revision().publish()

        # Create a new default site
        Site.objects.create(  # type: ignore
            hostname=host_name,
            site_name=site_name,
            root_page_id=homepage.id,
            is_default_site=True,
        )



from wagtail.contrib.modeladmin.options import (
    ModelAdmin,
    modeladmin_register,
)
from .snippet_models import Navbar


class NavbarAdmin(ModelAdmin):
    model = Navbar
    menu_icon = "link"  # change as required
    list_display = (
        "name",
        "custom_css_class",
        "custom_id",
    )
    search_fields = [
        "name",
    ]


modeladmin_register(NavbarAdmin)



#!/usr/bin/env python
import os
import sys

from django.core.management.templates import TemplateCommand
from django.core.management.utils import get_random_secret_key


CURRENT_PYTHON = sys.version_info[:2]
REQUIRED_PYTHON = (3, 4)

if CURRENT_PYTHON < REQUIRED_PYTHON:
    sys.stderr.write(
        "This version of Wagtail requires Python {}.{} or above - you are running {}.{}\n".format(
            *(REQUIRED_PYTHON + CURRENT_PYTHON)
        )
    )
    sys.exit(1)


class CreateProject(TemplateCommand):
    """
    Based on django.core.management.startproject
    """

    help = "Creates the directory structure for a new Wagtail CRX project."
    missing_args_message = "You must provide a project name."

    def add_arguments(self, parser):
        parser.add_argument(
            "--sitename",
            help='Human readable name of your website or brand, e.g. "Mega Corp Inc."',
        )
        parser.add_argument(
            "--domain",
            help='Domain that will be used for your website in production, e.g. "www.example.com"',
        )
        super().add_arguments(parser)

    def handle(self, **options):
        # pop standard args
        project_name = options.pop("name")
        target = options.pop("directory")

        # Make sure given name is not already in use by another python package/module.
        try:
            __import__(project_name)
        except ImportError:
            pass
        else:
            sys.exit(
                "'%s' conflicts with the name of an existing "
                "Python module and cannot be used as a project "
                "name. Please try another name." % project_name
            )

        # Create a random SECRET_KEY to put it in the main settings.
        options["secret_key"] = get_random_secret_key()

        # Handle custom template logic
        import coderedcms

        crx_path = os.path.dirname(coderedcms.__file__)
        if not options["template"]:
            options["template"] = "basic"
        template_path = os.path.join(
            os.path.join(crx_path, "project_template"), options["template"]
        )

        # Check if provided template is built-in to coderedcms,
        # otherwise, do not change it.
        if os.path.isdir(template_path):
            options["template"] = template_path

        # Treat these files as Django templates to render the boilerplate.
        options["extensions"] = ["py", "md", "txt"]
        options["files"] = ["Dockerfile"]

        # Set options
        message = "Creating a Wagtail CRX project called %(project_name)s"

        if options.get("sitename"):
            message += " for %(sitename)s"
        else:
            options["sitename"] = project_name

        if options.get("domain"):
            message += " (%(domain)s)"
            # Strip protocol out of domain if it is present.
            options["domain"] = options["domain"].split("://")[-1]
            # Figure out www logic.
            if options["domain"].startswith("www."):
                options["domain_nowww"] = options["domain"].split("www.")[-1]
            else:
                options["domain_nowww"] = options["domain"]
        else:
            options["domain"] = "localhost"
            options["domain_nowww"] = options["domain"]

        # Add additional custom options to the context.
        options["coderedcms_release"] = coderedcms.release

        # Print a friendly message
        print(
            message
            % {
                "project_name": project_name,
                "sitename": options.get("sitename"),
                "domain": options.get("domain"),
            }
        )

        # Run command
        super().handle("project", project_name, target, **options)

        # Be a friend once again.
        print(
            "Success! %(project_name)s has been created"
            % {"project_name": project_name}
        )

        nextsteps = """
Next steps:
    1. cd %(directory)s/
    2. python manage.py migrate
    3. python manage.py createsuperuser
    4. python manage.py runserver
    5. Go to http://localhost:8000/admin/ and start editing!
"""
        print(nextsteps % {"directory": target if target else project_name})


COMMANDS = {
    "start": CreateProject(),
}


def prog_name():
    return os.path.basename(sys.argv[0])


def help_index():
    print(
        "Type '%s help <subcommand>' for help on a specific subcommand.\n"
        % prog_name()
    )
    print("Available subcommands:\n")
    for name, cmd in sorted(COMMANDS.items()):
        print("    %s%s" % (name.ljust(20), cmd.help))


def unknown_command(command):
    print("Unknown command: '%s'" % command)
    print("Type '%s help' for usage." % prog_name())
    sys.exit(1)


def main():
    try:
        command_name = sys.argv[1]
    except IndexError:
        help_index()
        return

    if command_name == "help":
        try:
            help_command_name = sys.argv[2]
        except IndexError:
            help_index()
            return

        try:
            command = COMMANDS[help_command_name]
        except KeyError:
            unknown_command(help_command_name)
            return

        command.print_help(prog_name(), help_command_name)
        return

    try:
        command = COMMANDS[command_name]
    except KeyError:
        unknown_command(command_name)
        return

    command.run_from_argv(sys.argv)


if __name__ == "__main__":
    main()



from django.core.management.base import BaseCommand
import csv
from os.path import exists
from django.apps import apps


class Command(BaseCommand):
    help = "Creating --model_name objects for --app_name according the file --path specified"

    _LAZY_LOADS = {}

    def get_model(self, app, model):
        """Wrapper around django's get_model."""
        if "get_model" not in self._LAZY_LOADS:
            self._lazy_load_get_model()

        _get_model = self._LAZY_LOADS["get_model"]
        return _get_model(app, model)

    def _lazy_load_get_model(self):
        """Lazy loading of get_model.
        get_model loads django.conf.settings, which may fail if
        the settings haven't been configured yet.
        """
        from django import apps as django_apps

        self._LAZY_LOADS["get_model"] = django_apps.apps.get_model

    def add_arguments(self, parser):
        parser.add_argument("--path", required=True, type=str, help="file path")
        parser.add_argument("--model_name", required=True, type=str, help="model name")
        parser.add_argument(
            "--app_name",
            required=True,
            type=str,
            help="django app name that the model is connected to",
        )
        parser.add_argument(
            "--refresh",
            type=str,
            help="if refresh=yes, clear all data in the model before import.",
        )
        parser.add_argument(
            "--delimiter", type=str, help="delimiter for csv file", default=","
        )

    def handle(self, *args, **options):
        file_path = options["path"]
        if not exists(file_path):
            self.stdout.write(f"File path does not exist: {file_path}")
            return
        app_name = options["app_name"]
        if not apps.is_installed(app_name):
            self.stdout.write(f"App name is not installed: {app_name}")
            return
        _model = self.get_model(options["app_name"], options["model_name"])
        if options["refresh"] == "yes":
            self.stdout.write(f"Refreshing model: {_model.__name__}")
            _model.objects.all().delete()
        with open(file_path, "r") as csv_file:
            reader = csv.reader(csv_file, delimiter=",", quotechar="'")
            header = next(reader)
            for row in reader:
                _object_dict = dict(zip(header, row))
                _model.objects.create(**_object_dict)
                str_from_dict = "\n".join(f"{k}\t{v}" for k, v in _object_dict.items())
                self.stdout.write(f"Created: {str_from_dict}")



"""
https://github.com/ataylor32/django-friendly-tag-loader/blob/master/src/friendlytagloader/templatetags/friendly_loader.py
Sadly, this repo has not been updated for 3 years
"""
import contextlib

from django import template
from django.template.base import TokenType
from django.template.defaulttags import (
    CommentNode,
    IfNode,
    LoadNode,
    find_library,
    load_from_library,
)
from django.template.smartif import Literal

register = template.Library()


@register.tag
def friendly_load(parser, token):
    """
    Tries to load a custom template tag set. Non existing tag libraries
    are ignored.

    This means that, if used in conjunction with ``if_has_tag``, you can try to
    load the comments template tag library to enable comments even if the
    comments framework is not installed.

    For example::

        {% load friendly_loader %}
        {% friendly_load comments webdesign %}

        {% if_has_tag render_comment_list %}
            {% render_comment_list for obj %}
        {% else %}
            {% if_has_tag lorem %}
                {% lorem %}
            {% endif_has_tag %}
        {% endif_has_tag %}
    """
    bits = token.contents.split()
    if len(bits) >= 4 and bits[-2] == "from":
        # from syntax is used; load individual tags from the library
        name = bits[-1]
        with contextlib.suppress(template.TemplateSyntaxError):
            lib = find_library(parser, name)
            subset = load_from_library(lib, name, bits[1:-2])
            parser.add_library(subset)
    else:
        # one or more libraries are specified; load and add them to the parser
        for name in bits[1:]:
            with contextlib.suppress(template.TemplateSyntaxError):
                lib = find_library(parser, name)
                parser.add_library(lib)
    return LoadNode()


def do_if_has_tag(parser, token, negate=False):
    """
    The logic for both ``{% if_has_tag %}`` and ``{% if not_has_tag %}``.

    Checks if all the given tags exist (or not exist if ``negate`` is ``True``)
    and then only parses the branch that will not error due to non-existing
    tags.

    This means that the following is essentially the same as a
    ``{% comment %}`` tag::

      {% if_has_tag non_existing_tag %}
          {% non_existing_tag %}
      {% endif_has_tag %}

    Another example is checking a built-in tag. This will always render the
    current year and never FAIL::

      {% if_has_tag now %}
          {% now "Y" %}
      {% else %}
          FAIL
      {% endif_has_tag %}
    """
    bits = list(token.split_contents())
    if len(bits) < 2:
        raise template.TemplateSyntaxError("%r takes at least one arguments" % bits[0])
    end_tag = f"end{bits[0]}"
    has_tag = all(tag in parser.tags for tag in bits[1:])
    has_tag = (not negate and has_tag) or (negate and not has_tag)
    nodelist_true = nodelist_false = CommentNode()
    if has_tag:
        nodelist_true = parser.parse(("else", end_tag))
        token = parser.next_token()
        if token.contents == "else":
            parser.skip_past(end_tag)
    else:
        while parser.tokens:
            token = parser.next_token()
            if token.token_type == TokenType.BLOCK and token.contents == end_tag:
                return IfNode(
                    [(Literal(has_tag), nodelist_true), (None, nodelist_false)]
                )
            elif token.token_type == TokenType.BLOCK and token.contents == "else":
                break
        nodelist_false = parser.parse((end_tag,))
        parser.next_token()
    return IfNode([(Literal(has_tag), nodelist_true), (None, nodelist_false)])


@register.tag
def if_has_tag(parser, token):
    """
    Do something if all given tags are loaded::

       {% load friendly_loader %}
       {% friendly_load webdesign %}

       {% if_has_tag lorem %}
            {% lorem %}
       {% else %}
            Non dummy content goes here!
       {% endif_has_tag %}

    When given multiple arguments each and every tag in the list has to be
    available. This means that the following will render nothing::

       {% if_has_tag now nonexisting_tag %}
           {% now "Y" %}
       {% endif_has_tag %}
    """
    return do_if_has_tag(parser, token)


@register.tag
def ifnot_has_tag(parser, token):
    """
    Do something unless any given tag is loaded::

       {% load friendly_loader %}
       {% friendly_load comments %}

       {% ifnot_has_tag render_comment_list %}
            Comment support has been disabled.
       {% else %}
            {% render_comment_list for obj %}
       {% endifnot_has_tag %}

    In the case of multiple arguments, the condition will trigger if any tag in
    the list is unavailable. This means that the following will still render
    the current year::

       {% ifnot_has_tag now nonexisting_tag %}
           {% now "Y" %}
       {% endifnot_has_tag %}
    """
    return do_if_has_tag(parser, token, True)



"""
Default creatable pages used in Cjk CMS, for jump-starting new websites
without having to create a new page types.
Feel free to replace this file with your own configuration,
in your Wagtail project. Copy+paste and modify as needed.
"""
from django.utils.translation import gettext_lazy as _
from . import (
    CjkcmsArticlePage,
    CjkcmsArticleIndexPage,
    CjkcmsWebPage,
)
from cjkcms.fields import CjkcmsStreamField
from cjkcms.blocks import LAYOUT_STREAMBLOCKS, CONTENT_STREAMBLOCKS


class ArticlePage(CjkcmsArticlePage):
    """
    Article, suitable for news or blog content.
    """

    class Meta:
        verbose_name = _("Article")
        ordering = ["-first_published_at"]

    # Only allow this page to be created beneath an ArticleIndexPage.
    # parent_page_types = ['website.ArticleIndexPage']

    # Override to CjkcmsStreamField to get rid of migration issues
    # when modifying CONTENT_STREAMBLOCKS.
    body = CjkcmsStreamField(
        CONTENT_STREAMBLOCKS, null=True, blank=True, use_json_field=True
    )

    template = "cjkcms/pages/article_page.html"
    amp_template = "cjkcms/pages/article_page.amp.html"
    search_template = "cjkcms/pages/article_page.search.html"
    search_filterable = True


class ArticleIndexPage(CjkcmsArticleIndexPage):
    """
    Shows a list of article sub-pages.
    """

    # Override to CjkcmsStreamField to get rid of migration issues
    # when modifying LAYOUT_STREAMBLOCKS.
    body = CjkcmsStreamField(
        LAYOUT_STREAMBLOCKS, null=True, blank=True, use_json_field=True
    )

    class Meta:
        verbose_name = _("Article Landing Page")

    index_order_by_default = ""

    # Override to specify custom index ordering choice/default.
    index_query_pagemodel = "cjkcms.ArticlePage"

    # Only allow ArticlePages beneath this page.
    subpage_types = ["cjkcms.ArticlePage"]

    template = "cjkcms/pages/article_index_page.html"


class WebPage(CjkcmsWebPage):
    """
    General use page with featureful streamfield and SEO attributes.
    """

    # Override to CjkcmsStreamField to get rid of migration issues
    # when modifying LAYOUT_STREAMBLOCKS.
    body = CjkcmsStreamField(
        LAYOUT_STREAMBLOCKS, null=True, blank=True, use_json_field=True
    )

    class Meta:
        verbose_name = _("Web Page")

    template = "cjkcms/pages/web_page.html"
